Applications
============
For convenience a launcher function was created. It creates a tkinter root application and starts a tomography GUI application.


.. autofunction:: tomotok.gui.apps.launcher
    :noindex:

